@@ -24,6 +24,8 @@
 #include <Lum/Base/L10N.h>
 #include <Lum/Base/String.h>
 
+#include <Lum/Def/Menu.h>
+
 #include <Lum/Button.h>
 #include <Lum/Combo.h>
 #include <Lum/Dialog.h>
@@ -101,18 +103,19 @@ public:
 
     SetMain(vert);
 
-    Lum::MenuDesc *menu=new Lum::MenuDesc();
+    Lum::Def::Menu *menu=Lum::Def::Menu::Create();
 
     menu
-      ->AddMenuItemSub(_ld(menuProject))
-        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
-    menu
-      ->AddMenuItemSub(_ld(menuEdit))
-        ->AddMenuItemAction(_ld(menuEditSettings),configureAction);
-    menu
-      ->AddMenuItemSub(_ld(menuHelp))
-        ->AddMenuItemAction(_ld(menuHelpHelp),NULL)
-        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
+      ->GroupProject()
+        ->ActionQuit(GetClosedAction())
+      ->End()
+      ->GroupEdit()
+        ->ActionSettings(configureAction)
+      ->End()
+      ->GroupHelp()
+        //->Action(Lum::Def::Action(Lum::Def::Desc(_ld(menuHelpHelp)),NULL))
+        ->ActionAbout(aboutAction)
+      ->End();
 
     SetMenu(menu);
 
